Welcome to AWSM's Documentation!
======================================

.. include:: readme.rst

.. toctree::
   :maxdepth: 2

   readme
   installation
   usage
   configuration
   contributing
   config_ref
   api
   authors
   history

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
